@@ -8,8 +8,7 @@ sdpar <- function(object,  ...) cat("No method defined for class:",class(object)
 
 setGeneric("sdpar", function(object,  ...) standardGeneric("sdpar"))
 
-setMethod("sdpar", "dtiData",
-          function(object,
+setMethod("sdpar", "dtiData", function(object,
                    level = NULL,
                    sdmethod = "sd",
                    interactive = TRUE,
@@ -1087,7 +1086,7 @@ z <- .Fortran("getmask",
               as.double(prop),
               s0=double(prod(object@ddim)),
               mask=logical(prod(object@ddim)),
-              DUP=FALSE,
+              DUP=TRUE,
               PACKAGE="dti")[c("s0","mask")]
 } else {
 z <- list(s0=object@si[,,,object@s0ind],mask=array(TRUE,object@ddim))
@@ -1115,7 +1114,7 @@ z <- .Fortran("getmask",
               as.double(prop),
               s0=double(prod(ddim)),
               mask=logical(prod(ddim)),
-              DUP=FALSE,
+              DUP=TRUE,
               PACKAGE="dti")[c("s0","mask")]
 } else {
 z <- list(s0=object,mask=array(TRUE,dim(object)))
