@@ -749,236 +749,6 @@ C  do not adapt on the sphere !!!
 C$OMP END DO NOWAIT
 C$OMP END PARALLEL
 C$OMP FLUSH(thn,ni)
-      RETURN
-      END
-      subroutine adsmse3c(y,y0,th,ni,th0,ni0,fsi2,fsi02,mask,ns,n1,
-     1                n2,n3,ngrad,lambda,ws0,ncores,ind,w,n,ind0,w0,
-     2                n0,thn,nin,th0n,ni0n,sw,swy,thi,nii,fsi2i)
-C   
-C  Multi-shell version (differs in dimension of th 
-C  KL-distance based on all spheres and Gauss-approximation only
-C  see ~polzehl/latex/1211_simplemetric/Rcode/Figuregaussapprox.r 
-C  for approximative KL-distance between non-central chi distributions
-C
-C   perform adaptive smoothing on SE(3) multishell including s0
-C   y  -  si images
-C   y0 -  mean s0 image
-C   th -  estimated/interpolated \E si on all shells (including 0 shell)
-C   ni -  corresponding sum of weights
-C   th0 -  estimated/interpolated \E s0 and mean_g(\E si) on all other shells  
-C   ni0 -  corresponding sum of weights
-C   mask - head mask
-C   ns   - number of shells (including 0 shell)
-C   n1,n2,n3,ngrad - dimensions, number of gradients (bv!=0)
-C   lambda - skale parameter
-C   ws0  - relative weight for information from s0 images (should be in [0,1])
-C   ncoils - df/2 of \chi distributions
-C   minlev - expectation of central chi distr. (needed in variance estimates)
-C   ncores - number of cores
-C   ind    - index vectors for si weighting schemes 
-C   w    - corresponding weights
-C   n    - number of si weights
-C   ind0    - index vectors for s0 weighting schemes 
-C   w0    - corresponding weights
-C   n0    - number of s0 weights
-C   thn   - new estimates of \E si
-C   thn0   - new estimates of \E s0
-C   nin   - new sum of weight for si
-C   ni0n   - new sum of weight for s0
-C...sw,swy,si,thi,nii - working areas
-C   ind(.,i) contains coordinate indormation corresponding to positive
-C   location weights in w(i) for si images
-C   ind(.,i)[1:5] are j1-i1,j2-i2,j3-i3, i4 and j4 respectively 
-C
-      implicit logical (a-z)
-      integer ns,n1,n2,n3,ngrad,n,n0,ind(5,n),ind0(3,n0),ncores
-      logical mask(n1,n2,n3)
-      real*8 y(n1,n2,n3,ngrad),y0(n1,n2,n3),th(ns,n1,n2,n3,ngrad),
-     1     ni(ns,n1,n2,n3,ngrad),th0(ns,n1,n2,n3),ni0(ns,n1,n2,n3),
-     2     thn(n1,n2,n3,ngrad),th0n(n1,n2,n3),fsi2(ns,n1,n2,n3,ngrad),
-     3     nin(n1,n2,n3,ngrad),ni0n(n1,n2,n3),fsi02(ns,n1,n2,n3)
-      real*8 w(n),w0(n0),lambda,thi(ns,ncores),ws0,fsi2i(ns,ncores),
-     4     sw(ngrad,ncores),swy(ngrad,ncores),nii(ns,ncores)
-      integer iind,i,i1,i2,i3,i4,j1,j2,j3,j4,thrednr,k
-      real*8 sz,z,sw0,swy0
-!$      integer omp_get_thread_num
-!$      external omp_get_thread_num
-      thrednr = 1
-
-C$OMP PARALLEL DEFAULT(NONE)
-C$OMP& SHARED(ns,n1,n2,n3,ngrad,n,n0,ind,ind0,ncoils,ncores,y,y0,
-C$OMP&       th,ni,th0,ni0,w,w0,thn,th0n,nin,ni0n,thi,sw,swy,nii,
-C$OMP&       lambda,mask,ws0,fsi2,fsi02,fsi2i)
-C$OMP& PRIVATE(iind,i,i1,i2,i3,i4,j1,j2,j3,j4,thrednr,k,sz,z,
-C$OMP&       sw0,swy0)
-C$OMP DO SCHEDULE(GUIDED)
-C  First si - images
-      DO iind=1,n1*n2*n3
-!$         thrednr = omp_get_thread_num()+1
-C returns value in 0:(ncores-1)
-         i1=mod(iind,n1)
-         if(i1.eq.0) i1=n1
-         i2=mod((iind-i1)/n1+1,n2)
-         if(i2.eq.0) i2=n2
-         i3=(iind-i1-(i2-1)*n1)/n1/n2+1         
-         if(.not.mask(i1,i2,i3)) CYCLE
-         DO i4=1,ngrad
-            sw(i4,thrednr)=0.d0
-            swy(i4,thrednr)=0.d0
-         END DO
-         i4=0
-         DO i=1,n
-            if(ind(4,i).ne.i4) THEN
-C   by construction ind(4,.) should have same values consequtively
-               i4 = ind(4,i)
-               DO k=1,ns
-                  fsi2i(k,thrednr)=fsi2(k,i1,i2,i3,i4)
-                  thi(k,thrednr) = th(k,i1,i2,i3,i4)
-                  nii(k,thrednr) = ni(k,i1,i2,i3,i4)/lambda
-               END DO
-               nii(1,thrednr)=ws0*nii(1,thrednr)
-            END IF
-            j1=i1+ind(1,i)
-            if(j1.le.0.or.j1.gt.n1) CYCLE
-            j2=i2+ind(2,i)
-            if(j2.le.0.or.j2.gt.n2) CYCLE
-            j3=i3+ind(3,i)
-            if(j3.le.0.or.j3.gt.n3) CYCLE
-            if(.not.mask(j1,j2,j3)) CYCLE          
-            j4=ind(5,i)
-C adaptation 
-            if(lambda.lt.1d10) THEN
-               sz=0.d0
-               DO k=1,ns
-                  z=(thi(k,thrednr)-th(k,j1,j2,j3,j4))
-                  sz=sz+nii(k,thrednr)*z*z/
-     1                        (fsi2(k,j1,j2,j3,j4)+fsi2i(k,thrednr))
-               END DO
-C  do not adapt on the sphere !!! 
-            ELSE
-               sz=0.d0
-            END IF
-            if(sz.ge.1.d0) CYCLE
-            z=w(i)*min(1.d0,2.d0-2.d0*sz)
-            sw(i4,thrednr)=sw(i4,thrednr)+z
-            swy(i4,thrednr)=swy(i4,thrednr)+z*y(j1,j2,j3,j4)
-         END DO
-C  now opposite directions
-         DO i=1,n
-            if(ind(1,i).eq.0) CYCLE
-            if(ind(4,i).ne.i4) THEN
-C   by construction ind(4,.) should have same values consequtively
-               i4 = ind(4,i)
-               DO k=1,ns
-                  fsi2i(k,thrednr)=fsi2(k,i1,i2,i3,i4)
-                  thi(k,thrednr) = th(k,i1,i2,i3,i4)
-                  nii(k,thrednr) = ni(k,i1,i2,i3,i4)/lambda
-               END DO
-               nii(1,thrednr)=ws0*nii(1,thrednr)
-C  first component corresponds to S0 image, ws0 is used to downweight its influence
-C  when smoothing diffusion weighted data
-            END IF
-C
-C   handle case j1-i1 < 0 which is not contained in ind 
-C   using axial symmetry
-C
-            j1=i1-ind(1,i)
-            if(j1.le.0.or.j1.gt.n1) CYCLE
-            j2=i2-ind(2,i)
-            if(j2.le.0.or.j2.gt.n2) CYCLE
-            j3=i3-ind(3,i)
-            if(j3.le.0.or.j3.gt.n3) CYCLE
-            if(.not.mask(j1,j2,j3)) CYCLE          
-            j4=ind(5,i)
-            if(lambda.lt.1d10) THEN
-               sz=0.d0
-               DO k=1,ns
-                  z=(thi(k,thrednr)-th(k,j1,j2,j3,j4))
-                  sz=sz+nii(k,thrednr)*z*z/
-     1                        (fsi2(k,j1,j2,j3,j4)+fsi2i(k,thrednr))
-               END DO
-C  do not adapt on the sphere !!! 
-            ELSE
-               sz=0.d0
-            END IF
-            if(sz.ge.1.d0) CYCLE
-            z=w(i)*min(1.d0,2.d0-2.d0*sz)
-            sw(i4,thrednr)=sw(i4,thrednr)+z
-            swy(i4,thrednr)=swy(i4,thrednr)+z*y(j1,j2,j3,j4)
-         END DO
-         DO i4=1,ngrad
-            thn(i1,i2,i3,i4) = swy(i4,thrednr)/sw(i4,thrednr)
-            nin(i1,i2,i3,i4) = sw(i4,thrednr)
-         END DO
-C    now the s0 image in iind
-         sw0=0.d0
-         swy0=0.d0
-         DO k=1,ns
-            thi(k,thrednr) = th0(k,i1,i2,i3)
-            nii(k,thrednr) = ni0(k,i1,i2,i3)/lambda
-            fsi2i(k,thrednr)=fsi02(k,i1,i2,i3)
-         END DO
-         DO i=1,n0
-            j1=i1+ind0(1,i)
-            if(j1.le.0.or.j1.gt.n1) CYCLE
-            j2=i2+ind0(2,i)
-            if(j2.le.0.or.j2.gt.n2) CYCLE
-            j3=i3+ind0(3,i)
-            if(j3.le.0.or.j3.gt.n3) CYCLE
-            if(.not.mask(j1,j2,j3)) CYCLE          
-C adaptation 
-            if(lambda.lt.1d10) THEN
-               sz=0.d0
-               DO k=1,ns
-                  z=(thi(k,thrednr)-th0(k,j1,j2,j3))
-                  sz=sz+nii(k,thrednr)*z*z/
-     1                        (fsi02(k,j1,j2,j3)+fsi2i(k,thrednr))
-               END DO
-C  do not adapt on the sphere !!! 
-            ELSE
-               sz=0.d0
-            END IF
-            if(sz.ge.1.d0) CYCLE
-            z=w0(i)*min(1.d0,2.d0-2.d0*sz)
-            sw0=sw0+z
-            swy0=swy0+z*y0(j1,j2,j3)
-         END DO
-C  now opposite directions
-         DO i=1,n0
-            if(ind0(1,i).eq.0) CYCLE
-C
-C   handle case j1-i1 < 0 which is not contained in ind 
-C   using axial symmetry
-C
-            j1=i1-ind0(1,i)
-            if(j1.le.0.or.j1.gt.n1) CYCLE
-            j2=i2-ind0(2,i)
-            if(j2.le.0.or.j2.gt.n2) CYCLE
-            j3=i3-ind0(3,i)
-            if(j3.le.0.or.j3.gt.n3) CYCLE
-            if(.not.mask(j1,j2,j3)) CYCLE          
-            if(lambda.lt.1d10) THEN
-               sz=0.d0
-               DO k=1,ns
-                  z=(thi(k,thrednr)-th0(k,j1,j2,j3))
-                  sz=sz+nii(k,thrednr)*z*z/
-     1                        (fsi02(k,j1,j2,j3)+fsi2i(k,thrednr))
-               END DO
-C  do not adapt on the sphere !!! 
-            ELSE
-               sz=0.d0
-            END IF
-            if(sz.ge.1.d0) CYCLE
-            z=w0(i)*min(1.d0,2.d0-2.d0*sz)
-            sw0=sw0+z
-            swy0=swy0+z*y0(j1,j2,j3)
-         END DO
-         th0n(i1,i2,i3) = swy0/sw0
-         ni0n(i1,i2,i3) = sw0
-      END DO
-C$OMP END DO NOWAIT
-C$OMP END PARALLEL
-C$OMP FLUSH(thn,nin,th0n,ni0n)
       RETURN
       END
       subroutine adsmse3s(y,y0,th,ni,th0,ni0,fsi2,fsi02,mask,ns,n1,
@@ -1230,221 +1000,6 @@ C  do not adapt on the sphere !!!
       END DO
 C$OMP END DO NOWAIT
 C$OMP END PARALLEL
-C$OMP FLUSH(thn,nin,th0n,ni0n)
-      RETURN
-      END
-      subroutine adsmse3q(y,y0,th,ni,th0,ni0,mask,ns,nsp1,n1,n2,n3,
-     1                ngrad,lambda,ncores,ind,w,n,
-     2                ind0,w0,n0,thn,nin,th0n,ni0n,sw,swy,thi,nii)
-C   
-C  Multi-shell version (differs in dimension of th 
-C  KL-distance based on all spheres and Gauss-approximation only
-C
-C   perform adaptive smoothing on SE(3) multishell including s0
-C   y  -  si images
-C   y0 -  mean s0 image
-C   th -  estimated/interpolated \E si on all shells (including 0 shell)
-C   ni -  corresponding sum of weights
-C   th0 -  estimated/interpolated \E s0 and mean_g(\E si) on all other shells  
-C   ni0 -  corresponding sum of weights
-C   mask - head mask
-C   ns   - number of shells 
-C   nsp1   - number of shells (including 0 shell)
-C   n1,n2,n3,ngrad - dimensions, number of gradients (bv!=0)
-C   lambda - skale parameter
-C   ncores - number of cores
-C   ind    - index vectors for si weighting schemes 
-C   w    - corresponding weights
-C   n    - number of si weights
-C   ind0    - index vectors for s0 weighting schemes 
-C   w0    - corresponding weights
-C   n0    - number of s0 weights
-C   thn   - new estimates of \E si
-C   thn0   - new estimates of \E s0
-C   nin   - new sum of weight for si
-C   ni0n   - new sum of weight for s0
-C...sw,swy,si,thi,nii - working areas
-C   ind(.,i) contains coordinate indormation corresponding to positive
-C   location weights in w(i) for si images
-C   ind(.,i)[1:5] are j1-i1,j2-i2,j3-i3, i4 and j4 respectively 
-C
-      implicit logical (a-z)
-      integer ns,nsp1,n1,n2,n3,ngrad,n,n0,ind(5,n),ind0(3,n0),ncores
-      logical mask(n1,n2,n3)
-      real*8 y(n1,n2,n3,ngrad),y0(n1,n2,n3),th(ns,n1,n2,n3,ngrad),
-     1    ni(ns,n1,n2,n3,ngrad),th0(nsp1,n1,n2,n3),ni0(nsp1,n1,n2,n3),
-     2    thn(n1,n2,n3,ngrad),th0n(n1,n2,n3),
-     3    nin(n1,n2,n3,ngrad),ni0n(n1,n2,n3)
-      real*8 w(n),w0(n0),lambda,thi(nsp1,ncores),s0i,
-     1      sw(ngrad,ncores),swy(ngrad,ncores),nii(nsp1,ncores)
-      integer iind,i,i1,i2,i3,i4,j1,j2,j3,j4,thrednr,k
-      real*8 sz,z,sw0,swy0
-!$      integer omp_get_thread_num
-!$      external omp_get_thread_num
-      thrednr = 1
-C$OMP PARALLEL DEFAULT(NONE)
-C$OMP& SHARED(ns,nsp1,n1,n2,n3,ngrad,n,n0,ind,ind0,ncores,y,y0,
-C$OMP&       th,ni,th0,ni0,w,w0,thn,th0n,nin,ni0n,thi,sw,swy,nii,
-C$OMP&       lambda,mask)
-C$OMP& PRIVATE(iind,i,i1,i2,i3,i4,j1,j2,j3,j4,thrednr,k,sz,z,
-C$OMP&       sw0,swy0,s0i)
-C$OMP DO SCHEDULE(GUIDED)
-C  First si - images
-      DO iind=1,n1*n2*n3
-!$         thrednr = omp_get_thread_num()+1
-C returns value in 0:(ncores-1)
-         i1=mod(iind,n1)
-         if(i1.eq.0) i1=n1
-         i2=mod((iind-i1)/n1+1,n2)
-         if(i2.eq.0) i2=n2
-         i3=(iind-i1-(i2-1)*n1)/n1/n2+1         
-         if(.not.mask(i1,i2,i3)) CYCLE
-         DO i4=1,ngrad
-            sw(i4,thrednr)=0.d0
-            swy(i4,thrednr)=0.d0
-         END DO
-         i4=0
-         s0i = th0(1,i1,i2,i3)
-         DO i=1,n
-            if(ind(4,i).ne.i4) THEN
-C   by construction ind(4,.) should have same values consequtively
-               i4 = ind(4,i)
-               DO k=1,ns
-                  thi(k,thrednr) = th(k,i1,i2,i3,i4)
-                  nii(k,thrednr) = ni(k,i1,i2,i3,i4)/lambda*s0i*s0i
-               END DO
-            END IF
-            j1=i1+ind(1,i)
-            if(j1.le.0.or.j1.gt.n1) CYCLE
-            j2=i2+ind(2,i)
-            if(j2.le.0.or.j2.gt.n2) CYCLE
-            j3=i3+ind(3,i)
-            if(j3.le.0.or.j3.gt.n3) CYCLE
-            if(.not.mask(j1,j2,j3)) CYCLE          
-            j4=ind(5,i)
-C adaptation 
-            if(lambda.lt.1d10) THEN
-               sz=0.d0
-               DO k=1,ns
-                  z=thi(k,thrednr)-th(k,j1,j2,j3,j4)
-                  sz=sz+nii(k,thrednr)*z*z
-               END DO
-C  do not adapt on the sphere !!! 
-            ELSE
-               sz=0.d0
-            END IF
-            if(sz.ge.1.d0) CYCLE
-            z=w(i)*min(1.d0,2.d0-2.d0*sz)
-            sw(i4,thrednr)=sw(i4,thrednr)+z
-            swy(i4,thrednr)=swy(i4,thrednr)+z*y(j1,j2,j3,j4)
-         END DO
-C  now opposite directions
-         DO i=1,n
-            if(ind(1,i).eq.0) CYCLE
-            if(ind(4,i).ne.i4) THEN
-C   by construction ind(4,.) should have same values consequtively
-               i4 = ind(4,i)
-               DO k=1,ns
-                  thi(k,thrednr) = th(k,i1,i2,i3,i4)
-                  nii(k,thrednr) = ni(k,i1,i2,i3,i4)/lambda*s0i*s0i
-               END DO
-            END IF
-C
-C   handle case j1-i1 < 0 which is not contained in ind 
-C   using axial symmetry
-C
-            j1=i1-ind(1,i)
-            if(j1.le.0.or.j1.gt.n1) CYCLE
-            j2=i2-ind(2,i)
-            if(j2.le.0.or.j2.gt.n2) CYCLE
-            j3=i3-ind(3,i)
-            if(j3.le.0.or.j3.gt.n3) CYCLE
-            if(.not.mask(j1,j2,j3)) CYCLE          
-            j4=ind(5,i)
-            if(lambda.lt.1d10) THEN
-               sz=0.d0
-               DO k=1,ns
-                  z=thi(k,thrednr)-th(k,j1,j2,j3,j4)
-                  sz=sz+nii(k,thrednr)*z*z
-               END DO
-C  do not adapt on the sphere !!! 
-            ELSE
-               sz=0.d0
-            END IF
-            if(sz.ge.1.d0) CYCLE
-            z=w(i)*min(1.d0,2.d0-2.d0*sz)
-            sw(i4,thrednr)=sw(i4,thrednr)+z
-            swy(i4,thrednr)=swy(i4,thrednr)+z*y(j1,j2,j3,j4)
-         END DO
-         DO i4=1,ngrad
-            thn(i1,i2,i3,i4) = swy(i4,thrednr)/sw(i4,thrednr)
-            nin(i1,i2,i3,i4) = sw(i4,thrednr)
-         END DO
-C    now the s0 image in iind
-         sw0=0.d0
-         swy0=0.d0
-         DO k=1,nsp1
-            thi(k,thrednr) = th0(k,i1,i2,i3)
-            nii(k,thrednr) = ni0(k,i1,i2,i3)/lambda
-         END DO
-         DO i=1,n0
-            j1=i1+ind0(1,i)
-            if(j1.le.0.or.j1.gt.n1) CYCLE
-            j2=i2+ind0(2,i)
-            if(j2.le.0.or.j2.gt.n2) CYCLE
-            j3=i3+ind0(3,i)
-            if(j3.le.0.or.j3.gt.n3) CYCLE
-            if(.not.mask(j1,j2,j3)) CYCLE          
-C adaptation 
-            if(lambda.lt.1d10) THEN
-               sz=0.d0
-               DO k=1,nsp1
-                  z=thi(k,thrednr)-th0(k,j1,j2,j3)
-                  sz=sz+nii(k,thrednr)*z*z
-               END DO
-C  do not adapt on the sphere !!! 
-            ELSE
-               sz=0.d0
-            END IF
-            if(sz.ge.1.d0) CYCLE
-            z=w0(i)*min(1.d0,2.d0-2.d0*sz)
-            sw0=sw0+z
-            swy0=swy0+z*y0(j1,j2,j3)
-         END DO
-C  now opposite directions
-         DO i=1,n0
-            if(ind0(1,i).eq.0) CYCLE
-C
-C   handle case j1-i1 < 0 which is not contained in ind 
-C   using axial symmetry
-C
-            j1=i1-ind0(1,i)
-            if(j1.le.0.or.j1.gt.n1) CYCLE
-            j2=i2-ind0(2,i)
-            if(j2.le.0.or.j2.gt.n2) CYCLE
-            j3=i3-ind0(3,i)
-            if(j3.le.0.or.j3.gt.n3) CYCLE
-            if(.not.mask(j1,j2,j3)) CYCLE          
-            if(lambda.lt.1d10) THEN
-               sz=0.d0
-               DO k=1,nsp1
-                  z=thi(k,thrednr)-th0(k,j1,j2,j3)
-                  sz=sz+nii(k,thrednr)*z*z
-               END DO
-C  do not adapt on the sphere !!! 
-            ELSE
-               sz=0.d0
-            END IF
-            if(sz.ge.1.d0) CYCLE
-            z=w0(i)*min(1.d0,2.d0-2.d0*sz)
-            sw0=sw0+z
-            swy0=swy0+z*y0(j1,j2,j3)
-         END DO
-         th0n(i1,i2,i3) = swy0/sw0
-         ni0n(i1,i2,i3) = sw0
-      END DO
-C$OMP END DO NOWAIT
-C$OMP END PARALLEL
 C$OMP FLUSH(thn,nin,th0n,ni0n)
       RETURN
       END
@@ -1654,98 +1209,6 @@ C  Approximation by Patnaik (1949)
       fj = z1/cj
       kldisnc1 = lgfj-lgfi+0.5d0*(fj*dlog(cj)+
      1                 fici/cj-fj*dgfi)
-      RETURN
-      END
-      subroutine awsvchi2(y,th,ni,mask,n1,n2,n3,lambda,ncoils,
-     1                    thn,th2,ni2,ldf,h,vext)
-C   model=1 takes noncentral Chi-sq values in y0
-C   model=0 takes noncentral Chi values in y0
-C   perform adaptive smoothing on R^3
-C   ind(.,i) contains coordinate indormation corresponding to positive
-C   location weights in w(i)
-C   ind(.,i)[1:5] are j1-i1,j2-i2,j3-i3, i4 and j4 respectively 
-C
-      implicit logical (a-z)
-      integer n1,n2,n3,ncoils
-      logical mask(n1,n2,n3)
-      real*8 y(n1,n2,n3),th(n1,n2,n3),ni(*),thn(*),
-     1       th2(*),ni2(*),lambda,h,vext(2),
-     2       ldf(n1,n2,n3)
-      integer i1,i2,i3,j1,j2,j3,cw1,cw2,cw3,i,n
-      real*8 z,lgfi,dgfi,fici,df,kval,w,w0,h2,sw,sw2,swy,swy2,yj,
-     1       z1,z2,z3
-      real*8 kldisnc1
-      external kldisnc1
-      df=2.d0*ncoils
-      h2=h*h
-      cw1=int(h)
-      cw2=int(h/vext(1))
-      cw3=int(h/vext(2))
-      n = n1*n2*n3
-C  precompute values of lgamma(corrected df/2) in each voxel
-C$OMP PARALLEL DEFAULT(NONE)
-C$OMP& SHARED(n1,n2,n3,ncoils,mask,y,th,ni,thn,th2,ni2,h,vext,ldf,n)
-C$OMP& FIRSTPRIVATE(lambda,cw1,cw2,cw3,df,h2)
-C$OMP& PRIVATE(i1,i2,i3,j1,j2,j3,i,z,lgfi,dgfi,fici,kval,w,w0,
-C$OMP& sw,sw2,swy,swy2,yj,z1,z2,z3)
-C$OMP DO SCHEDULE(GUIDED)
-      DO i=1,n
-         i1=mod(i,n1)
-         if(i1.eq.0) i1=n1
-         i2=mod((i-i1)/n1+1,n2)
-         if(i2.eq.0) i2=n2
-         i3=(i-i1-(i2-1)*n1)/n1/n2+1         
-         call lgstats(th(i1,i2,i3),df,1,ldf(i1,i2,i3))
-      END DO
-C$OMP END DO
-C$OMP BARRIER
-C$OMP DO SCHEDULE(GUIDED)
-      DO i=1,n
-         i1=mod(i,n1)
-         if(i1.eq.0) i1=n1
-         i2=mod((i-i1)/n1+1,n2)
-         if(i2.eq.0) i2=n2
-         i3=(i-i1-(i2-1)*n1)/n1/n2+1         
-         if(.not.mask(i1,i2,i3)) CYCLE
-         sw=0.d0
-         swy=0.d0
-         sw2=0.d0
-         swy2=0.d0
-         kval = lambda/ni(i)
-         call ncstats0(th(i1,i2,i3),ldf(i1,i2,i3),df,
-     1                       1,lgfi,dgfi,fici)
-         DO j1=max(1,i1-cw1),min(i1+cw1,n1)
-            z1=j1-i1
-            z1=z1*z1
-            DO j2=max(1,i2-cw2),min(i2+cw2,n2)
-               z2=(j2-i2)*vext(1)
-               z2=z2*z2
-               DO j3=max(1,i3-cw3),min(i3+cw3,n3)
-                  if(.not.mask(j1,j2,j3)) CYCLE
-                  z3=(j3-i3)*vext(2)
-                  w0=z1+z2+z3*z3
-                  if(w0.ge.h2) CYCLE
-                  w0=1.d0-w0/h2 
-                  z=kldisnc1(lgfi,dgfi,fici,th(j1,j2,j3),
-     1                       ldf(j1,j2,j3),df,1)
-                  if(z.ge.kval) CYCLE
-                  w=w0*min(1.d0,2.d0-2.d0*z/kval)
-                  sw=sw+w
-                  sw2=sw2+w*w
-                  yj=y(j1,j2,j3)
-                  swy=swy+w*yj
-                  swy2=swy2+w*yj*yj
-               END DO
-            END DO
-         END DO
-         thn(i) = swy/sw
-         th2(i) = swy2/sw
-         ni(i) = sw
-         ni2(i) = sw2
-      END DO
-C$OMP END DO NOWAIT
-C$OMP END PARALLEL
-C$OMP FLUSH(thn,ni,ni2,th2)
       RETURN
       END
       subroutine paramw3(h,vext,ind,w,n)
